@@ -787,7 +787,7 @@ def get_bit_string_from_byte(target_byte):
         if (type(target_byte) != int) or (target_byte > 255 or target_byte < 0):
             print("type of target_byte or target_byte is error, do not get bit")
             return
-        return format(0x0100 + result, 'b')[1:]
+        return format(0x0100 + target_byte, 'b')[1:]
     except Exception as e:
         print(e)
         return
